.. _api_dataset:

Representation of Datasets (:mod:`pydicom.dataset`)
===================================================

.. currentmodule:: pydicom.dataset

Representation of DICOM datasets and related functions.

.. autosummary::
   :toctree: generated/

   Dataset
   FileDataset
   FileMetaDataset
   PrivateBlock
   validate_file_meta
